pystagram.graph_api.components.tag package — pystagram 0.1 documentation

# pystagram.graph_api.components.tag package

## Submodules

## pystagram.graph_api.components.tag.product_tag module

class pystagram.graph_api.components.tag.product_tag.ProductTag(product_id: str, x: float, y: float, merchant_id: str | None = None)

  Bases: `Tag`

  dict() → dict
  info() → dict

## pystagram.graph_api.components.tag.tag module

class pystagram.graph_api.components.tag.tag.Tag

  Bases: `ABC`

  abstract dict() → dict

## pystagram.graph_api.components.tag.user_tag module

class pystagram.graph_api.components.tag.user_tag.UserTag(username: str, x: float, y: float)

  Bases: `Tag`

  dict() → dict

## Module contents